{ config, lib, pkgs, ... }:

let
  unstable = import <nixos-unstable> { config.allowUnfree = true; };
  cloudstation = pkgs.callPackage (import ../packages/cloudstation.nix) {};
  nagstamon = pkgs.libsForQt5.callPackage (import ../packages/nagstamon.nix) {};
in {

  security.pki.certificateFiles = [
    ../dotfiles/certs/NetzmarktCA.crt
    ../dotfiles/certs/vcenter.netzmarkt.lan.crt
  ];

  networking.extraHosts = ''
    10.100.7.11 mon.netzmarkt.de
    85.10.233.162 live.bonedo.de

    172.20.0.2 hubble.kind
    172.20.0.2 dashboard.kind
    172.20.0.2 grafana.kind
    172.20.0.2 alert.kind
  '';

  environment.systemPackages = with pkgs; [
    (import ../packages/oc311.nix)
    (import ../packages/oc46.nix)
    (import ../packages/openshift-install-4.5.nix)
    # (import ../packages/vaultsink.nix) needs opensource verson
    cloudstation
    nagstamon

    drone-cli
    go-jira
    govc
    ttyd
    unstable.discord
    unstable.google-cloud-sdk
    unstable.slack
    unstable.velero

    unstable.obs-studio
    unstable.obs-studio-plugins.wlrobs
  ];
}
